import React from 'react';
import { useTheme } from '../components/context/ThemeContext';
import { useTranslation } from 'react-i18next';
import { Youtube, Linkedin, Instagram, Phone, Mail, MapPin } from 'lucide-react';

const Footer = () => {
  const { isDarkMode } = useTheme();
  const { t } = useTranslation();
  
  const currentYear = new Date().getFullYear();

  const socialLinks = [
    { icon: Youtube, href: 'https://youtube.com', color: 'hover:bg-red-600' },
    { icon: Instagram, href: 'https://www.instagram.com/dinamik.rezistans?igsh=cmY4a2V5bm1tajBx', color: 'hover:bg-pink-600' },
    { icon: Linkedin, href: 'https://linkedin.com', color: 'hover:bg-blue-600' }
  ];

  const categories = [
    { name: t('categories.Dirençler.name'), href: '/direncler' },
    { name: t('categories.Rezistanslar.name'), href: '/rezistanslar' },
    { name: t('categories.Sıcak Yolluk Sistemleri.subcategories.Sıcak Yolluk Ünite'), href: '/product/sicakyolluksistemleri' },
    { name: t('categories.Pano Isıtıcısı.name'), href: '/product/panoisitici' }
  ];

  return (
    <footer className={`w-full ${
      isDarkMode ? 'bg-black text-white border-zinc-900' : 'bg-white text-gray-900 border-gray-200'
    } border-t`}>
      <div className="container mx-auto px-4 sm:px-6 lg:px-8 py-12">
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-8">
          <div>
            <h3 className={`text-xl font-bold mb-6 ${
              isDarkMode ? 'text-zinc-200' : 'text-gray-900'
            } relative after:content-[''] after:block after:w-12 after:h-1 ${
              isDarkMode ? 'after:bg-emerald-500' : 'after:bg-blue-500'
            } after:mt-2`}>
              {t('footer.quickMenu')}
            </h3>
            <ul className="space-y-4">
              <li>
                <a 
                  href="/"
                  className={`relative inline-block ${
                    isDarkMode 
                      ? 'text-zinc-400 hover:text-emerald-400' 
                      : 'text-gray-600 hover:text-blue-600'
                  } after:content-[''] after:absolute after:w-0 after:h-0.5 after:left-0 after:bottom-0 after:transition-all after:duration-300 ${
                    isDarkMode 
                      ? 'after:bg-emerald-400' 
                      : 'after:bg-blue-600'
                  } hover:after:w-full`}
                >
                  {t('nav.home')}
                </a>
              </li>
              <li>
                <a 
                  href="/products"
                  className={`relative inline-block ${
                    isDarkMode 
                      ? 'text-zinc-400 hover:text-emerald-400' 
                      : 'text-gray-600 hover:text-blue-600'
                  } after:content-[''] after:absolute after:w-0 after:h-0.5 after:left-0 after:bottom-0 after:transition-all after:duration-300 ${
                    isDarkMode 
                      ? 'after:bg-emerald-400' 
                      : 'after:bg-blue-600'
                  } hover:after:w-full`}
                >
                  {t('nav.allproducts')}
                </a>
              </li>
              <li>
                <a 
                  href="/products"
                  className={`relative inline-block ${
                    isDarkMode 
                      ? 'text-zinc-400 hover:text-emerald-400' 
                      : 'text-gray-600 hover:text-blue-600'
                  } after:content-[''] after:absolute after:w-0 after:h-0.5 after:left-0 after:bottom-0 after:transition-all after:duration-300 ${
                    isDarkMode 
                      ? 'after:bg-emerald-400' 
                      : 'after:bg-blue-600'
                  } hover:after:w-full`}
                >
                  {t('nav.products')}
                </a>
              </li>
              <li>
                <a 
                  href="/about"
                  className={`relative inline-block ${
                    isDarkMode 
                      ? 'text-zinc-400 hover:text-emerald-400' 
                      : 'text-gray-600 hover:text-blue-600'
                  } after:content-[''] after:absolute after:w-0 after:h-0.5 after:left-0 after:bottom-0 after:transition-all after:duration-300 ${
                    isDarkMode 
                      ? 'after:bg-emerald-400' 
                      : 'after:bg-blue-600'
                  } hover:after:w-full`}
                >
                  {t('nav.about')}
                </a>
              </li>
            </ul>
          </div>

          <div>
            <h3 className={`text-xl font-bold mb-6 ${
              isDarkMode ? 'text-zinc-200' : 'text-gray-900'
            } relative after:content-[''] after:block after:w-12 after:h-1 ${
              isDarkMode ? 'after:bg-emerald-500' : 'after:bg-blue-500'
            } after:mt-2`}>
              {t('footer.categories')}
            </h3>
            <ul className="space-y-4">
              {categories.map((category) => (
                <li key={category.name}>
                  <a 
                    href={category.href}
                    className={`relative inline-block ${
                      isDarkMode 
                        ? 'text-zinc-400 hover:text-emerald-400' 
                        : 'text-gray-600 hover:text-blue-600'
                    } after:content-[''] after:absolute after:w-0 after:h-0.5 after:left-0 after:bottom-0 after:transition-all after:duration-300 ${
                      isDarkMode 
                        ? 'after:bg-emerald-400' 
                        : 'after:bg-blue-600'
                    } hover:after:w-full`}
                  >
                    {category.name}
                  </a>
                </li>
              ))}
            </ul>
          </div>

          <div>
            <h3 className={`text-xl font-bold mb-6 ${
              isDarkMode ? 'text-zinc-200' : 'text-gray-900'
            } relative after:content-[''] after:block after:w-12 after:h-1 ${
              isDarkMode ? 'after:bg-emerald-500' : 'after:bg-blue-500'
            } after:mt-2`}>
              {t('footer.contactInfo')}
            </h3>
            <ul className="space-y-4">
              {[
                { Icon: Phone, text: '+90 539 362 1233' },
                { Icon: Mail, text: 'mahmut@orionrezistans.com' },
                { Icon: MapPin, text: 'Şerifali, Edep Sk. No:38, 34776 Ümraniye/İstanbul' }
              ].map(({ Icon, text }, index) => (
                <li key={index} className="group flex items-center space-x-3">
                  <div className={`p-2 rounded ${
                    isDarkMode ? 'bg-zinc-900 group-hover:bg-emerald-500/20' : 'bg-gray-100'
                  } transition-colors duration-300`}>
                    <Icon className={`h-5 w-5 ${
                      isDarkMode 
                        ? 'text-emerald-400 group-hover:text-emerald-300' 
                        : 'text-blue-500'
                    } transition-colors duration-300`} />
                  </div>
                  <span className={`${
                    isDarkMode 
                      ? 'text-zinc-400 group-hover:text-emerald-400' 
                      : 'text-gray-600 group-hover:text-blue-500'
                  } transition-colors duration-300`}>
                    {text}
                  </span>
                </li>
              ))}
            </ul>
          </div>

          <div>
            <h3 className={`text-xl font-bold mb-6 ${
              isDarkMode ? 'text-zinc-200' : 'text-gray-900'
            } relative after:content-[''] after:block after:w-12 after:h-1 ${
              isDarkMode ? 'after:bg-emerald-500' : 'after:bg-blue-500'
            } after:mt-2`}>
              {t('footer.workingHours')}
            </h3>
            <ul className="space-y-4">
              {[
                { days: t('footer.days'), hours: '08:30 - 18:30' },
                { days: t('footer.Saturday'), hours: '08:30 - 18:30' },
                { days: t('footer.Sunday'), hours: t('footer.closed') }
              ].map((schedule, index) => (
                <li key={index} className="flex justify-between items-center group">
                  <span className={`font-medium transition-colors duration-300 ${
                    isDarkMode 
                      ? 'text-zinc-400 group-hover:text-emerald-400' 
                      : 'text-gray-600 group-hover:text-blue-500'
                  }`}>
                    {schedule.days}
                  </span>
                  <span className={`transition-colors duration-300 ${
                    isDarkMode 
                      ? 'text-zinc-400 group-hover:text-emerald-400' 
                      : 'text-gray-600 group-hover:text-blue-500'
                  }`}>
                    {schedule.hours}
                  </span>
                </li>
              ))}
            </ul>
          </div>
        </div>

        <div className={`mt-12 pt-8 border-t ${
          isDarkMode ? 'border-zinc-900' : 'border-gray-200'
        }`}>
          <div className="flex flex-col items-center space-y-6">
            <div className="flex space-x-8">
              {socialLinks.map(({ icon: Icon, href, color }) => (
                <a 
                  key={href}
                  href={href}
                  target="_blank"
                  rel="noopener noreferrer"
                  className={`p-3 rounded ${
                    isDarkMode 
                      ? 'bg-zinc-900 hover:bg-emerald-500/20' 
                      : 'bg-gray-100'
                  } ${isDarkMode ? '' : color} group transition-all duration-300 hover:-translate-y-1`}
                >
                  <Icon className={`h-4 w-4 ${
                    isDarkMode 
                      ? 'text-emerald-400 group-hover:text-emerald-300' 
                      : 'text-gray-600 group-hover:text-white'
                  } transition-colors duration-300`} />
                </a>
              ))}
            </div>
            <p className={`${
              isDarkMode ? 'text-zinc-400' : 'text-gray-600'
            } text-sm text-center font-medium`}>
              © {currentYear} {t('footer.allRightsReserved')}
            </p>
          </div>
        </div>
      </div>
    </footer>
  );
};

export default Footer;
